@@ -67,7 +67,6 @@ class TestAssembla:
         # the exception is working.
         try:
             api = API(auth=('_','_',))
-            api.spaces = lambda: []
             api.check_credentials()
             raise Exception('Should have thrown an AssemblaError.')
         except AssemblaError as e:
@@ -195,7 +194,7 @@ class TestAssembla:
         assert ticket.summary is not None
         assert ticket.reporter_id is not None
         assert ticket.priority is not None
-        assert ticket.status is not None
+        assert ticket.status_name is not None
         # Check that fields have been converted to Python types
         assert type(ticket.number) is int
         assert type(ticket.priority) is int
@@ -279,7 +278,7 @@ class TestAssembla:
             assert ticket.summary is not None
             assert ticket.reporter_id is not None
             assert ticket.priority is not None
-            assert ticket.status is not None
+            assert ticket.status_name is not None
             # Check that fields have been converted to Python types
             assert type(ticket.number) is int
             assert type(ticket.priority) is int
